@@ -9,10 +9,10 @@ from google.cloud.pubsub_v1.subscriber.futures import StreamingPullFuture
 from google.cloud.pubsub_v1.subscriber.message import Message
 from google.cloud.pubsub_v1.types import FlowControl
 from typing import Any, Coroutine, Dict, Generic, Sequence
-from maleo.logging.config import Config
-from maleo.schemas.application import OptionalApplicationContext
+from maleo.logging.config import LogConfig
+from maleo.schemas.application import OptApplicationContext
 from maleo.schemas.resource import AggregateField, ResourceIdentifier
-from maleo.types.misc import OptionalPathOrString
+from maleo.types.misc import OptPathOrStr
 from maleo.utils.exception import extract_details
 from ..base import GOOGLE_RESOURCE, GoogleClientManager
 from ..types import OptionalCredentials
@@ -35,11 +35,11 @@ class GooglePubSub(
     def __init__(
         self,
         config: PubSubConfig[PublisherConfigT, SubscriptionsConfigT],
-        log_config: Config,
+        log_config: LogConfig,
         *,
-        application_context: OptionalApplicationContext = None,
+        application_context: OptApplicationContext = None,
         credentials: OptionalCredentials = None,
-        credentials_path: OptionalPathOrString = None,
+        credentials_path: OptPathOrStr = None,
     ) -> None:
         super().__init__(
             PUBSUB_RESOURCE.aggregate(),
