@@ -1,5 +1,5 @@
 from pydantic import BaseModel, Field
-from typing import Annotated, Generic, Optional, TypeVar
+from typing import Annotated, Generic, TypeVar
 
 
 class SubscriptionConfig(BaseModel):
@@ -19,9 +19,8 @@ class SubscriptionsConfig(BaseModel):
     pass
 
 
-SubscriptionsConfigT = TypeVar(
-    "SubscriptionsConfigT", bound=Optional[SubscriptionsConfig]
-)
+OptSubscriptionsConfig = SubscriptionsConfig | None
+SubscriptionsConfigT = TypeVar("SubscriptionsConfigT", bound=OptSubscriptionsConfig)
 
 
 class SubscriptionsConfigMixin(BaseModel, Generic[SubscriptionsConfigT]):
