@@ -3,4 +3,4 @@ from typing import Callable, TypeVar
 
 
 R = TypeVar("R")
-MessageController = Callable[[Message], R]
+MessageController = Callable[[str, Message], R]
