@@ -10,12 +10,12 @@ from maleo.database.managers import RedisManager
 from maleo.database.enums import CacheOrigin, CacheLayer
 from maleo.database.utils import build_cache_namespace, build_cache_key
 from maleo.enums.expiration import Expiration
-from maleo.logging.config import Config
+from maleo.logging.config import LogConfig
 from maleo.logging.enums import Level
-from maleo.schemas.application import OptionalApplicationContext
-from maleo.schemas.connection import OptionalConnectionContext
+from maleo.schemas.application import OptApplicationContext
+from maleo.schemas.connection import OptConnectionContext
 from maleo.schemas.data import DataPair
-from maleo.schemas.error.enums import Code as ErrorCode
+from maleo.schemas.error.enums import ErrorCode
 from maleo.schemas.exception.factory import Factory as MaleoExceptionFactory
 from maleo.schemas.operation.enums import (
     OperationType,
@@ -36,12 +36,12 @@ from maleo.schemas.response import (
     CreateSingleDataResponse,
     ReadSingleDataResponse,
 )
-from maleo.schemas.security.authentication import OptionalAnyAuthentication
-from maleo.schemas.security.authorization import OptionalAnyAuthorization
-from maleo.schemas.security.impersonation import OptionalImpersonation
-from maleo.types.misc import OptionalPathOrString
-from maleo.types.string import OptionalString
-from maleo.types.uuid import OptionalUUID
+from maleo.schemas.security.authentication import OptAnyAuthentication
+from maleo.schemas.security.authorization import OptAnyAuthorization
+from maleo.schemas.security.impersonation import OptImpersonation
+from maleo.types.misc import OptPathOrStr
+from maleo.types.string import OptStr
+from maleo.types.uuid import OptUUID
 from maleo.utils.exception import extract_details
 from .base import GOOGLE_RESOURCE, GoogleClientManager
 from .types import OptionalCredentials
@@ -60,12 +60,12 @@ class Asset(BaseModel):
 class GoogleCloudStorage(GoogleClientManager):
     def __init__(
         self,
-        log_config: Config,
+        log_config: LogConfig,
         *,
-        application_context: OptionalApplicationContext = None,
+        application_context: OptApplicationContext = None,
         credentials: OptionalCredentials = None,
-        credentials_path: OptionalPathOrString = None,
-        bucket_name: OptionalString = None,
+        credentials_path: OptPathOrStr = None,
+        bucket_name: OptStr = None,
         redis: RedisManager,
     ) -> None:
         super().__init__(
@@ -118,14 +118,14 @@ class GoogleCloudStorage(GoogleClientManager):
         self,
         content: bytes,
         location: str,
-        content_type: OptionalString = None,
+        content_type: OptStr = None,
         *,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        root_location_override: OptionalString = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        root_location_override: OptStr = None,
         make_public: bool = False,
         use_cache: bool = True,
         expiration: Expiration = Expiration.EXP_15MN,
@@ -215,12 +215,12 @@ class GoogleCloudStorage(GoogleClientManager):
         self,
         location: str,
         *,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-        root_location_override: OptionalString = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+        root_location_override: OptStr = None,
         use_cache: bool = True,
         expiration: Expiration = Expiration.EXP_15MN,
     ) -> SingleDataResponse[Asset, None]:
